@@ -12,7 +12,7 @@ from logilab.common.compat import any
 from logilab.common.deprecation import deprecated
 
 from cubicweb import QueryError, Binary, Unauthorized
-from cubicweb.selectors import is_instance
+from cubicweb.predicates import is_instance
 from cubicweb.entities import AnyEntity, fetch_config, adapters
 
 from cubes.vcsfile import queries
