@@ -15,7 +15,7 @@ from logilab.mtconverter import need_guess, guess_mimetype_and_encoding
 
 from cubicweb import QueryError, ValidationError, Binary
 from cubicweb.server import hook, session
-from cubicweb.selectors import is_instance, score_entity, configuration_values
+from cubicweb.predicates import is_instance, score_entity, configuration_values
 
 from cubes.vcsfile import IMMUTABLE_ATTRIBUTES, bridge
 
