@@ -7,8 +7,7 @@
 __docformat__ = "restructuredtext en"
 _ = unicode
 
-from cubicweb.selectors import (one_line_rset, is_instance, rql_condition,
-                                but_etype, score_entity)
+from cubicweb.predicates import (one_line_rset, is_instance, rql_condition, score_entity)
 from cubicweb.web.action import Action
 from cubicweb.web.views.actions import CopyAction
 
