@@ -13,9 +13,9 @@ from copy import copy
 from logilab.mtconverter import xml_escape
 from logilab.common.decorators import cached
 
-from cubicweb.selectors import (match_form_params, match_kwargs,
-                                is_instance, specified_etype_implements,
-                                match_edited_type)
+from cubicweb.predicates import (match_form_params, match_kwargs,
+                                 is_instance, specified_etype_implements,
+                                 match_edited_type)
 from cubicweb.view import EntityView
 from cubicweb.web import (Redirect, RequestError, controller, uicfg, form,
                           formfields as ff, formwidgets as fw)
