@@ -11,7 +11,7 @@ from logilab.mtconverter import TransformError, xml_escape
 
 from cubicweb import Unauthorized, tags
 from cubicweb.mttransforms import ENGINE
-from cubicweb.selectors import is_instance, score_entity
+from cubicweb.predicates import is_instance, score_entity
 from cubicweb.view import EntityView
 from cubicweb.web import uicfg
 from cubicweb.web.views import (ibreadcrumbs, idownloadable, tableview,
